@@ -83,6 +83,9 @@ def funcToParamDict(func, title=None, **overrides):
     for name in checkNames:
         # May be none if this is an override name after function accepted kwargs
         param = funcParams.get(name)
+        if param is not None and param.kind is param.VAR_POSITIONAL:
+          # Cannot yet handle positional-only
+          continue
         pgDict = createFuncParameter(name, param, parsedDoc, overrides, title)
         children.append(pgDict)
     return out
@@ -103,7 +106,7 @@ def createFuncParameter(name, signatureParam, docDict, overridesDict, title=None
         # Also, maybe override was a value without a type, so give a sensible default
         default = signatureParam.default
         signatureDict = {'value': default,
-                         'type': type(default).__name__}
+                         'type': type(default).__name__.lower()}
     else:
         signatureDict = {}
     # Doc takes precedence over signature for any value information
