@@ -161,13 +161,13 @@ def serAsFrame(ser: pd.Series):
   return ser.to_frame().T
 
 def create_addMenuAct(mainWin: QtWidgets.QWidget, parentMenu: QtWidgets.QMenu, title: str, asMenu=False) \
-    -> t.Union[QtWidgets.QMenu, QtWidgets.QAction]:
+    -> t.Union[QtWidgets.QMenu, QtGui.QAction]:
   menu = None
   if asMenu:
     menu = QtWidgets.QMenu(title, mainWin)
     act = menu.menuAction()
   else:
-    act = QtWidgets.QAction(title)
+    act = QtGui.QAction(title)
   parentMenu.addAction(act)
   if asMenu:
     return menu
