@@ -522,7 +522,7 @@ class ParamEditor(QtWidgets.QDockWidget):
   def createMenuOpt(self, overrideName=None, parentMenu: QtWidgets.QMenu=None):
     if overrideName is None:
       overrideName = self.name
-    editAct = QtWidgets.QAction('Open ' + overrideName, self)
+    editAct = QtGui.QAction('Open ' + overrideName, self)
     if self.saveDir is None:
       # No save options are possible, just use an action instead of dropdown menu
       newMenuOrAct = editAct
@@ -599,7 +599,7 @@ class ParamEditor(QtWidgets.QDockWidget):
     if removeExistingChildren:
       encounteredSep = False
       for ii, action in enumerate(parentMenu.children()):
-        action: QtWidgets.QAction
+        action: QtGui.QAction
         if encounteredSep:
           parentMenu.removeAction(action)
         elif action.isSeparator():
