@@ -159,7 +159,7 @@ class KeySequenceParameterItem(parameterTypes.WidgetParameterItem):
 
   # def contextMenuEvent(self, ev: QtGui.QContextMenuEvent):
   #   menu = self.contextMenu
-  #   delAct = QtWidgets.QAction('Set Blank')
+  #   delAct = QtGui.QAction('Set Blank')
   #   delAct.triggered.connect(lambda: self.widget.setValue(''))
   #   menu.addAction(delAct)
   #   menu.exec(ev.globalPos())
@@ -298,7 +298,7 @@ class ProcGroupParameterItem(parameterTypes.GroupParameterItem):
     opts = self.param.opts
     flags = self.flags()
     if opts['process'].allowDisable:
-      flags |= QtCore.Qt.ItemFlag.ItemIsUserCheckable & (~QtCore.Qt.ItemFlag.ItemIsTristate)
+      flags |= QtCore.Qt.ItemFlag.ItemIsUserCheckable & (~QtCore.Qt.ItemFlag.ItemIsAutoTristate)
     self.setFlags(flags)
 
   def setData(self, column, role, value):
