@@ -123,7 +123,7 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     # Win is provided by this plugin, so take it out of required keys if needed
     proc.input.keysFromPrevIO.discard('win')
     # Registration may have happened after attaching win ref, so ensure reference is valid here too
-    proc.updateInput(win=self.win, graceful=True)
+    proc.updateInput(win=self.win)
     if returnParam:
       return proc, param
     return proc
