@@ -52,7 +52,7 @@ class ShortcutsEditor(ParamEditor):
                        f'This is not the case for {func}')
     kwargs.setdefault('namePath', (clsNameOrGroup(overrideOwnerObj),))
     param = self._createSeq(shortcutOpts, **kwargs)
-    shc = QtWidgets.QShortcut(overrideOwnerObj)
+    shc = QtGui.QShortcut(overrideOwnerObj)
     shc.setContext(QtCore.Qt.ShortcutContext.WidgetWithChildrenShortcut)
 
     shc.activatedAmbiguously.connect(lambda: self.maybeAmbigWarning(param.value()))
@@ -69,7 +69,7 @@ class ShortcutsEditor(ParamEditor):
 
     return param
 
-  def registerAction(self, btnOpts: PrjParam, action: QtWidgets.QAction, **kwargs):
+  def registerAction(self, btnOpts: PrjParam, action: QtGui.QAction, **kwargs):
     self._checkUniqueShortcut(btnOpts)
 
     param = self._createSeq(btnOpts, **kwargs)
