@@ -1,4 +1,6 @@
 from __future__ import annotations
+
+import contextlib
 from contextlib import ExitStack
 
 import copy
@@ -69,30 +71,46 @@ class ParamContainer(MutableMapping):
     except KeyError:
       return self.params[item].value()
 
-  def copy(self):
-    return copy.copy(self)
+  def copy(self, deepCopyParams=True, deepCopyExtras=False, deepCopyAttrs=False):
+    ret = type(self)()
+    ret.__dict__.update(self.__dict__)
+    # Will be filled in later
+    ret.extras = {}
+    ret.params = {}
+    if deepCopyAttrs:
+      ret.__dict__ = copy.deepcopy(ret.__dict__)
+
+    if deepCopyExtras:
+      ret.extras = copy.deepcopy(self.extras)
+    else:
+      ret.extras = self.extras.copy()
+    # As of now, ret.copy()['param'] = value will still modify ret['param'] if `deepCopyParams` is false.
+    # Sometimes this may be desired, but doesn't follow the interface of dict.copy()['key'] = value preventing
+    # modification of the original dict's key
+    if deepCopyParams:
+      for param, val in self.params.items():
+        ret.params[param] = Parameter.create(**val.saveState())
+    else:
+      ret.params = self.params.copy()
+    return ret
+
+  def __copy__(self):
+    return self.copy()
 
   def __deepcopy__(self, memodict):
-    params = self.params
-    # Deepcopy has trouble working with parameters, so temporarily hide them
-    # until after the opre
-    self.params = {}
-    try:
-      deep = pickle.loads(pickle.dumps(self))
-    finally:
-      self.params = params
-    for param, val in params.items():
-      deep.params[param] = Parameter.create(**val.saveState())
-    return deep
+    return self.copy(deepCopyExtras=True, deepCopyAttrs=True)
 
   def __str__(self):
     pieces = []
-    if len(self.extras):
-      pieces.append(f'Extra: {self.extras}')
-    if len(self.params):
-      pieces.append(f'Params: {self.params}')
+    for subdict, title in zip([self.extras, self.params], ['Extra', 'Params']):
+      if len(subdict):
+        pieces.append(f'{title}: {subdict}')
+      else:
+        pieces.append(f'{title}: <No keys>')
     return '\n'.join(pieces)
 
+  def __repr__(self):
+    return str(self)
 
 class ProcessIO(ParamContainer):
   """
@@ -206,7 +224,6 @@ class ProcessIO(ParamContainer):
         paramDict[newName] = paramDict[key]
         del paramDict[key]
 
-
 class ProcessStage(ABC):
   name: str
   input: ProcessIO = None
@@ -216,6 +233,11 @@ class ProcessStage(ABC):
   result: t.Optional[ProcessIO] = None
   inMap: t.Union[t.List[str], t.Dict[str, str]] = None
   outMap: t.Union[t.List[str], t.Dict[str, str]] = None
+  nameForState = None
+  """
+  Can be overridden to appear as a different heading in a saved state. This is useful when e.g. loading a state
+  from its fully qualified (+ module) name. Should be overridden at the instance level
+  """
 
   class _DUPLICATE_INFO: pass
   """Identifies information that is the same in two contiguous stages"""
@@ -517,10 +539,11 @@ class AtomicProcess(ProcessStage):
       except Exception:
         return False
     saveIo = {k: v for k, v in self.input.items() if keepCond(k, v)}
+    saveName = self.nameForState or self.name
     if not saveIo:
-      state = self.name
+      state = saveName
     else:
-      state = {self.name: saveIo}
+      state = {saveName: saveIo}
     if includeMeta:
       state = self.addMetaProps(state, **metaFilterOpts)
     return state
@@ -544,7 +567,8 @@ class NestedProcess(ProcessStage):
     """
     atomic = AtomicProcess(func, **kwargs)
     numSameNames = sum(
-        atomic.name == stage.name.split('#')[0] for stage in self)
+      atomic.name == stage.name.split('#')[0] for stage in self
+    )
     if numSameNames > 0:
       atomic.name = f'{atomic.name}#{numSameNames+1}'
     if self.name is None:
@@ -619,7 +643,8 @@ class NestedProcess(ProcessStage):
     for stage in self:
       curState = stage.saveState(includeDefaults, includeMeta)
       stageStates.append(curState)
-    state = {self.name: stageStates}
+    saveName = self.nameForState or self.name
+    state = {saveName: stageStates}
     if includeMeta:
       state = self.addMetaProps(state, **metaFilterOpts)
     return state
@@ -634,7 +659,13 @@ class NestedProcess(ProcessStage):
 
   def flatten(self, copy=True, includeDisabled=True):
     if copy:
-      outProc = type(self)(self.name)
+      try:
+        # No need to copy nested structure
+        stages = self.stages
+        self.stages = []
+        outProc = _copy.copy(self)
+      finally:
+        self.stages = stages
     else:
       outProc = self
     outProc.stages = self._getFlatStages(includeDisabled)
@@ -739,4 +770,4 @@ class NestedProcess(ProcessStage):
           if np.array_equal(info[key], lastInfo[key]):
             validInfo[key] = cls._DUPLICATE_INFO
       validInfos.append(validInfo)
-    return validInfos
\ No newline at end of file
+    return validInfos
