@@ -303,7 +303,7 @@ class HoverScatter(pg.ScatterPlotItem):
 
   def hoverEvent(self, ev: QtGui.QHoverEvent):
     if not hasattr(ev, '_scenePos'): return
-    pts = self.pointsAt(ev.pos())
+    pts = self.pointsAt(ev.position() if hasattr(ev, 'position') else ev.localPos())
     if len(pts) > 0:
       pt = pts[-1]
       data = pt.data()
@@ -647,7 +647,7 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
 
   def mouseMoveEvent(self, ev: QtGui.QMouseEvent):
     super().mouseMoveEvent(ev)
-    pos = ev.pos()
+    pos = ev.position() if hasattr(ev, 'position') else ev.localPos()
     relpos = self.imgItem.mapFromScene(pos)
     xyCoord = np.array([relpos.x(), relpos.y()], dtype=int)
     if (self.imgItem.image is None
@@ -880,8 +880,6 @@ class MaskCompositor(ImageViewer):
 
     :param labelMask: Grayscale label mask of integers
     :param name: Name to identify this mask in the property editor
-    :param ignoreValue: Label values matching ``ignoreValue`` will be transparent in the mask overlay.
-    :param ignoreIfBlank: If *True* and the whole mask is the background color, no action will be performed
     :param clearOverlays: If *True*, `clearOverlays` will be called before adding this item. This is useful
       if only one mask is viewed at a time
     :param fullLabelMapInLegend: See ``updateLegendEntries`` -- this parameter is passed during legend creation
@@ -964,6 +962,8 @@ class MaskCompositor(ImageViewer):
       will update the global legend, meaning if {10 -> 'test'} is a legend entry, it will overwrite the old
       legend value for 10.
     :param backgroundValues: Represents label mask values that should be transparent in the overlay
+    :param updateOverlays: If *True*, overlay graphics will be refreshed to reflect these updates. Keep *False* if
+      several updates will happen in sequence.
     """
     if labelMap is None:
       labelMap = {}
